# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from decimal import Decimal
import django_google_adwords.models
import djmoney.models.fields


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('account_id', models.BigIntegerField(unique=True)),
                ('status', models.CharField(default=b'active', max_length=32, choices=[(b'active', b'Active'), (b'sync', b'Sync'), (b'inactive', b'Inactive')])),
                ('account', models.CharField(help_text=b'Account descriptive name', max_length=255, null=True, blank=True)),
                ('currency', models.CharField(help_text=b'Account currency code', max_length=255, null=True, blank=True)),
                ('account_last_synced', models.DateField(null=True, blank=True)),
                ('campaign_last_synced', models.DateField(null=True, blank=True)),
                ('ad_group_last_synced', models.DateField(null=True, blank=True)),
                ('ad_last_synced', models.DateField(null=True, blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Ad',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ad_id', models.BigIntegerField(help_text=b'Googles Ad ID')),
                ('ad_state', models.CharField(blank=True, max_length=20, null=True, choices=[(b'enabled', b'Enabled'), (b'paused', b'Paused'), (b'removed', b'Removed')])),
                ('ad_type', models.CharField(blank=True, max_length=20, null=True, choices=[(b'Other', b'Other'), (b'Image ad', b'Image Ad'), (b'Mobile ad', b'Mobile Ad'), (b'Product listing ad', b'Product Listing Ad'), (b'Display ad', b'Display Ad'), (b'Text ad', b'Text Ad'), (b'Third party ad', b'Third Party Ad'), (b'Dynamic search ad', b'Dynamic Search Ad')])),
                ('ad_approval_status', models.CharField(blank=True, max_length=20, null=True, choices=[(b'approved', b'Approved'), (b'approved (non family)', b'Approved (Non Family)'), (b'approved (adult)', b'Approved (Adult)'), (b'pending review', b'Pending Review'), (b'disapproved', b'Disapproved')])),
                ('destination_url', models.TextField(help_text=b'Destination URL', null=True, blank=True)),
                ('display_url', models.TextField(help_text=b'Display URL', null=True, blank=True)),
                ('ad', models.TextField(help_text=b'Ad/Headline', null=True, blank=True)),
                ('description_line_1', models.TextField(help_text=b'Description line 1', null=True, blank=True)),
                ('description_line_2', models.TextField(help_text=b'Description line 2', null=True, blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='AdGroup',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ad_group_id', models.BigIntegerField(unique=True)),
                ('ad_group', models.CharField(help_text=b'Ad group name', max_length=255, null=True, blank=True)),
                ('ad_group_state', models.CharField(blank=True, max_length=20, null=True, choices=[(b'enabled', b'Enabled'), (b'paused', b'Paused'), (b'removed', b'Removed')])),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Alert',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('type', models.CharField(max_length=100, choices=[(b'ACCOUNT_ON_TARGET', b'Account On Target'), (b'DECLINED_PAYMENT', b'Declined Payment'), (b'CREDIT_CARD_EXPIRING', b'Credit Card Expiring'), (b'ACCOUNT_BUDGET_ENDING', b'Account Budget Ending'), (b'CAMPAIGN_ENDING', b'Campaign Ending'), (b'PAYMENT_NOT_ENTERED', b'Payment Not Entered'), (b'MISSING_BANK_REFERENCE_NUMBER', b'Missing Bank Reference Number'), (b'CAMPAIGN_ENDED', b'Campaign Ended'), (b'ACCOUNT_BUDGET_BURN_RATE', b'Account Budget Burn Rate'), (b'USER_INVITE_PENDING', b'User Invite Pending'), (b'USER_INVITE_ACCEPTED', b'User Invite Accepted'), (b'MANAGER_LINK_PENDING', b'Manager Link Pending'), (b'ZERO_DAILY_SPENDING_LIMIT', b'Zero Daily Spending Limit'), (b'TV_ACCOUNT_ON_TARGET', b'TV Account On Target'), (b'TV_ACCOUNT_BUDGET_ENDING', b'TV Account Budget Ending'), (b'TV_ZERO_DAILY_SPENDING_LIMIT', b'TV Zero Daily Spending Limit'), (b'UNKNOWN', b'Unknown')])),
                ('severity', models.CharField(max_length=100, choices=[(b'GREEN', b'Green'), (b'YELLOW', b'Yellow'), (b'RED', b'Red'), (b'UNKNOWN', b'Unknown')])),
                ('occurred', models.DateTimeField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('account', models.ForeignKey(related_name='alerts', to='django_google_adwords.Account')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Campaign',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('campaign_id', models.BigIntegerField(unique=True)),
                ('campaign', models.CharField(help_text=b'Campaign name', max_length=255)),
                ('campaign_state', models.CharField(max_length=20, choices=[(b'enabled', b'Enabled'), (b'paused', b'Paused'), (b'removed', b'Removed')])),
                ('budget_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('budget', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Budget', null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('account', models.ForeignKey(related_name='campaigns', to='django_google_adwords.Account')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyAccountMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('device', models.CharField(help_text=b'Device', max_length=255, choices=[(b'Other', b'Other'), (b'Computers', b'Computers'), (b'Mobile devices with full browsers', b'Mobile devices with full browsers'), (b'Tablets with full browsers', b'Tablets with full browsers')])),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('content_impr_share', models.DecimalField(help_text=b'Content Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_rank', models.DecimalField(help_text=b'Content Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('cost_est_total_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_est_total_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / est. total conv.', null=True)),
                ('est_cross_device_conv', models.BigIntegerField(help_text=b'Est. cross-device conv.', null=True, blank=True)),
                ('est_total_conv_rate', models.DecimalField(help_text=b'Est. total conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value', models.DecimalField(help_text=b'Est. total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_click', models.DecimalField(help_text=b'Est. total conv. value / click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_cost', models.DecimalField(help_text=b'Est. total conv. value / cost', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv', models.BigIntegerField(help_text=b'Est. total conv.', null=True, blank=True)),
                ('search_exact_match_is', models.DecimalField(help_text=b'Search Exact match IS', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_impr_share', models.DecimalField(help_text=b'Search Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_lost_is_rank', models.DecimalField(help_text=b'Search Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_budget', models.DecimalField(help_text=b'Content Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_click_rate', models.DecimalField(help_text=b'Invalid click rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_clicks', models.BigIntegerField(help_text=b'Invalid clicks', null=True, blank=True)),
                ('search_lost_is_budget', models.DecimalField(help_text=b'Search Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('account', models.ForeignKey(related_name='metrics', to='django_google_adwords.Account')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyAdGroupMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('content_impr_share', models.DecimalField(help_text=b'Content Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_rank', models.DecimalField(help_text=b'Content Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('cost_est_total_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_est_total_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / est. total conv.', null=True)),
                ('est_cross_device_conv', models.BigIntegerField(help_text=b'Est. cross-device conv.', null=True, blank=True)),
                ('est_total_conv_rate', models.DecimalField(help_text=b'Est. total conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value', models.DecimalField(help_text=b'Est. total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_click', models.DecimalField(help_text=b'Est. total conv. value / click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_cost', models.DecimalField(help_text=b'Est. total conv. value / cost', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv', models.BigIntegerField(help_text=b'Est. total conv.', null=True, blank=True)),
                ('search_exact_match_is', models.DecimalField(help_text=b'Search Exact match IS', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_impr_share', models.DecimalField(help_text=b'Search Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_lost_is_rank', models.DecimalField(help_text=b'Search Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('bid_strategy_id', models.BigIntegerField(help_text=b'Bid Strategy ID', null=True, blank=True)),
                ('bid_strategy_name', models.CharField(max_length=255, null=True, blank=True)),
                ('bid_strategy_type', models.CharField(blank=True, max_length=40, null=True, help_text=b'Bid Strategy Type', choices=[(b'auto', b'Budget Optimizer'), (b'max/target cpa', b'Conversion Optimizer'), (b'cpc', b'Manual CPC'), (b'cpm', b'Manual CPM'), (b'Target search page location', b'Page One Promoted'), (b'max cpa percent', b'Percent CPA'), (b'Maximize clicks', b'Target Spend'), (b'Enhanced CPC', b'Enhanced CPC'), (b'Target CPA', b'Target CPA'), (b'Target ROAS', b'Target ROAS'), (b'None', b'None'), (b'unknown', b'Unknown')])),
                ('max_cpa_converted_clicks_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('max_cpa_converted_clicks', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Max. CPA (converted clicks)', null=True)),
                ('value_est_total_conv', models.DecimalField(help_text=b'Value / est. total conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_converted_click', models.DecimalField(help_text=b'Value / converted click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_conv', models.DecimalField(help_text=b'Value / conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('view_through_conv', models.BigIntegerField(help_text=b'View-through conv.', null=True, blank=True)),
                ('ad_group', models.ForeignKey(related_name='metrics', to='django_google_adwords.AdGroup')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyAdMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('value_converted_click', models.DecimalField(help_text=b'Value / converted click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_conv', models.DecimalField(help_text=b'Value / conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('view_through_conv', models.BigIntegerField(help_text=b'View-through conv.', null=True, blank=True)),
                ('ad', models.ForeignKey(related_name='metrics', to='django_google_adwords.Ad')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyCampaignMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('content_impr_share', models.DecimalField(help_text=b'Content Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_rank', models.DecimalField(help_text=b'Content Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('cost_est_total_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_est_total_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / est. total conv.', null=True)),
                ('est_cross_device_conv', models.BigIntegerField(help_text=b'Est. cross-device conv.', null=True, blank=True)),
                ('est_total_conv_rate', models.DecimalField(help_text=b'Est. total conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value', models.DecimalField(help_text=b'Est. total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_click', models.DecimalField(help_text=b'Est. total conv. value / click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_cost', models.DecimalField(help_text=b'Est. total conv. value / cost', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv', models.BigIntegerField(help_text=b'Est. total conv.', null=True, blank=True)),
                ('search_exact_match_is', models.DecimalField(help_text=b'Search Exact match IS', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_impr_share', models.DecimalField(help_text=b'Search Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_lost_is_rank', models.DecimalField(help_text=b'Search Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('bid_strategy_id', models.BigIntegerField(help_text=b'Bid Strategy ID', null=True, blank=True)),
                ('bid_strategy_name', models.CharField(max_length=255, null=True, blank=True)),
                ('bid_strategy_type', models.CharField(blank=True, max_length=40, null=True, help_text=b'Bid Strategy Type', choices=[(b'auto', b'Budget Optimizer'), (b'max/target cpa', b'Conversion Optimizer'), (b'cpc', b'Manual CPC'), (b'cpm', b'Manual CPM'), (b'Target search page location', b'Page One Promoted'), (b'max cpa percent', b'Percent CPA'), (b'Maximize clicks', b'Target Spend'), (b'Enhanced CPC', b'Enhanced CPC'), (b'Target CPA', b'Target CPA'), (b'Target ROAS', b'Target ROAS'), (b'None', b'None'), (b'unknown', b'Unknown')])),
                ('content_lost_is_budget', models.DecimalField(help_text=b'Content Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_click_rate', models.DecimalField(help_text=b'Invalid click rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_clicks', models.BigIntegerField(help_text=b'Invalid clicks', null=True, blank=True)),
                ('search_lost_is_budget', models.DecimalField(help_text=b'Search Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_converted_click', models.DecimalField(help_text=b'Value / converted click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_conv', models.DecimalField(help_text=b'Value / conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('view_through_conv', models.BigIntegerField(help_text=b'View-through conv.', null=True, blank=True)),
                ('campaign', models.ForeignKey(related_name='metrics', to='django_google_adwords.Campaign')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='ReportFile',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('file', models.FileField(max_length=255, null=True, upload_to=django_google_adwords.models.reportfile_file_upload_to, blank=True)),
                ('processed', models.BooleanField(default=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='adgroup',
            name='campaign',
            field=models.ForeignKey(related_name='ad_groups', to='django_google_adwords.Campaign'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='ad',
            name='ad_group',
            field=models.ForeignKey(related_name='ads', to='django_google_adwords.AdGroup'),
            preserve_default=True,
        ),
    ]
